@@ -4,7 +4,7 @@ from dolib.client import Client
 
 @pytest.mark.vcr
 @pytest.mark.block_network()
-def test_account():
+def test_account() -> None:
     client = Client(token="fake_token")
 
     account = client.account.get()
